// CPUHOGUI.C - implements the user interface for CPUHOG
// Author - Arnab Bhaduri
///////////////////////////////////////////////////////////////////

#define STRICT
#define NOGDI
#define NOIME

// Includes ///////////////////////////////////////////////////////

#include <windows.h>
#include <string.h>
#include <stdio.h>
#include "resource.h"
#include "cpuhog.h"

// Function prototypes ////////////////////////////////////////////

int   APIENTRY CPUHogDlgProc( HWND hDlg, WORD wMsg, LONG wParam,
                              LONG lParam );

// Static variables ///////////////////////////////////////////////

static UINT gnTimerID = 0;    // dlg timer ID

// WinMain - gets the module name and creates the dialog
///////////////////////////////////////////////////////////////////
int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPSTR lpCmdLine, int nCmdShow )
{
char  szPath[MAX_PATH + 1];
DWORD dwRet = 0;

if( GetModuleFileName(NULL, szPath, MAX_PATH) != 0 )
    {
    // extract file name from process path
    char *lpszName = strrchr( szPath, '.' );

    if( lpszName )
        *lpszName = '\0';
    lpszName = strrchr( szPath, '\\' );
    lpszName = lpszName == NULL ? szPath : lpszName + 1;

    // inform the hog module of the process name
    SetHogProcessName( lpszName );
    }
else
    {
    MessageBox( NULL, "Unable to read process name.", NULL,
                MB_ICONSTOP | MB_OK );
    return -1;
    }

return DialogBox( hInstance, (LPCSTR)"CPUHOGDLG", NULL,
                  (DLGPROC)CPUHogDlgProc );
}

// CPUHogDlgProc - dialog box procedure. Handles dialog init,
// refresh, input and shutdown.
///////////////////////////////////////////////////////////////////
int APIENTRY CPUHogDlgProc( HWND hDlg, WORD wMsg, LONG wParam,
                            LONG lParam )
{
switch( wMsg )
    {
    case WM_INITDIALOG:
        {
        // attempt to start the worker thread
        if( StartHog() == FALSE )
            {
            MessageBox( hDlg, "Unable to start worker thread",
                        NULL, MB_ICONSTOP | MB_OK );
            EndDialog( hDlg, FALSE );
            }
        else
            // start refresh timer
            gnTimerID = SetTimer( hDlg, 1234, 2000, NULL );

        return 1;
        }
    case WM_TIMER:
        {
        // refresh the display text
        HWND hDisplay = GetDlgItem( hDlg, IDC_DISPLAY );

        SetWindowText( hDisplay, GetHogStatusText() );
        return 1;
        }
    case WM_COMMAND:
        {
        switch (LOWORD(wParam))
            {
            case IDOK:
                {
                // terminate worker thread and clean up
                StopHog();
                KillTimer( hDlg, gnTimerID );
                EndDialog( hDlg, TRUE );
                return 1;
                }
            case ID_SET:
                {
                // set the new CPU utilization target
                HWND hWnd = GetDlgItem( hDlg, IDC_CPUPC );
                LONG lTmp = 101;
                char szBuff[10];

                GetWindowText( hWnd, szBuff, 3 );
                sscanf( szBuff, "%ld", &lTmp );
                if( lTmp > 0 && lTmp < 100 )
                    SetHogLevel( lTmp );
                else
                    MessageBeep( MB_ICONHAND );
                return 1;
                }
            }
        }
    default:
        return 0;
    }

return 0;
}

